Module: sems
Branch: master
Commit: 19c25e79f6e14d083be5bf29cfef68e4772909a1
URL:    
http://git.sip-router.org/cgi-bin/gitweb.cgi/sems/?a=commit;h=19c25e79f6e14d083be5bf29cfef68e4772909a1

Author: Stefan Sayer <[email protected]>
Committer: Stefan Sayer <[email protected]>
Date:   Fri Jul 22 15:10:19 2011 +0200

b/f: fixed pyqtgui for webconference with participant_id

---

 apps/webconference/pyqtgui/conftable.py     |    2 +-
 apps/webconference/pyqtgui/conftable.ui     |    2 +-
 apps/webconference/pyqtgui/webconference.py |   19 +++++++++++--------
 3 files changed, 13 insertions(+), 10 deletions(-)

diff --git a/apps/webconference/pyqtgui/conftable.py 
b/apps/webconference/pyqtgui/conftable.py
index 5892a52..c6f2f24 100644
--- a/apps/webconference/pyqtgui/conftable.py
+++ b/apps/webconference/pyqtgui/conftable.py
@@ -61,7 +61,7 @@ class Ui_MainWindow(object):
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
 
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", 
"miff", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", 
"conference call", None, QtGui.QApplication.UnicodeUTF8))
         self.buttonNew.setText(QtGui.QApplication.translate("MainWindow", 
"Call someone", None, QtGui.QApplication.UnicodeUTF8))
         self.label.setText(QtGui.QApplication.translate("MainWindow", 
"iptel.org\n"
 "webconference", None, QtGui.QApplication.UnicodeUTF8))
diff --git a/apps/webconference/pyqtgui/conftable.ui 
b/apps/webconference/pyqtgui/conftable.ui
index 061c325..478b1e0 100644
--- a/apps/webconference/pyqtgui/conftable.ui
+++ b/apps/webconference/pyqtgui/conftable.ui
@@ -10,7 +10,7 @@
    </rect>
   </property>
   <property name="windowTitle" >
-   <string>miff</string>
+   <string>conference call</string>
   </property>
   <property name="autoFillBackground" >
    <bool>true</bool>
diff --git a/apps/webconference/pyqtgui/webconference.py 
b/apps/webconference/pyqtgui/webconference.py
index dab45cd..402841f 100755
--- a/apps/webconference/pyqtgui/webconference.py
+++ b/apps/webconference/pyqtgui/webconference.py
@@ -23,9 +23,12 @@ from participant import *
 from callbox import *
 from account import *
 
 # URI for XMLRPC webconference control, set to your server
host:
+#CONTROL_URI="http://127.0.0.1:8090/";
 CONTROL_URI="https://webconference.iptel.org/control";
 
+print "Server Control URI: '%s' - change CONTROL_URI to use local SEMS 
instance" % CONTROL_URI
+
 # refresh in ms
 REFRESH_INTERVAL=1000
 
@@ -109,7 +112,7 @@ class StartQT4(QtGui.QMainWindow):
                        self.roomname = ""
                        for n in range(6):
                                self.roomname+=str(random.randint(0,9))
-                       code, result, adminpin, serverstatus = 
self.s.roomCreate(self.roomname)
+                       code, result, adminpin, serverstatus = 
self.s.di('webconference', 'roomCreate', self.roomname)
                        print "server status: %s " % serverstatus
                        if code == 0:
                                self.adminpin = adminpin
@@ -127,7 +130,7 @@ class StartQT4(QtGui.QMainWindow):
                self.timer.start(REFRESH_INTERVAL)
                
        def timer_hit(self):
-               res = self.s.roomInfo(self.roomname, self.adminpin)
+               res = self.s.di('webconference', 'roomInfo', self.roomname, 
self.adminpin)
                if res[0] != 0:
                        print "oh my god, can't see this room!"
                        return
@@ -139,7 +142,7 @@ class StartQT4(QtGui.QMainWindow):
                self.last_res = participants
                
                for part in participants:
-                       call_tag, number, status, reason, muted = part          
+                       call_tag, number, status, reason, muted, participant_id 
= part
                        found = False
                        for p in self.participants:
                                if p.callid == call_tag:
@@ -170,7 +173,7 @@ class StartQT4(QtGui.QMainWindow):
                        return
                
                print "now calling %s " % dlg_cb.num.text() 
-               res = self.s.dialout(self.roomname, self.adminpin, 
str(dlg_cb.num.text()),
+               res = self.s.di('webconference', 'dialout', self.roomname, 
self.adminpin, str(dlg_cb.num.text()),
                                self.call_user, self.call_domain, 
self.call_auth_user, self.call_pwd)
                if res[0] != 0:
                        print "oh, my dear, calling failed with code %d " % 
res[0]
@@ -183,14 +186,14 @@ class StartQT4(QtGui.QMainWindow):
                
        def part_ciao(self, id):
                print "ciao: ", id 
-               self.s.kickout(self.roomname, self.adminpin, 
self.participants[id].callid)
+               self.s.di('webconference', 'kickout', self.roomname, 
self.adminpin, self.participants[id].callid)
                
        def part_muted(self, id, s):
                print "mute: ", id, " is ", s
                if s:
-                       self.s.mute(self.roomname, self.adminpin, 
self.participants[id].callid)
+                       self.s.di('webconference', 'mute', self.roomname, 
self.adminpin, self.participants[id].callid)
                else:
-                       self.s.unmute(self.roomname, self.adminpin, 
self.participants[id].callid)
+                       self.s.di('webconference', 'unmute', self.roomname, 
self.adminpin, self.participants[id].callid)
                
                
@@ -23,9 +23,12 @@ from participant import *
 from account import *
 
-# URI for XMLRPC webconference control, set to your server
+# URI for XMLRPC webconference control, set to your server, e.g. for local 
host:
 

_______________________________________________
Semsdev mailing list
[email protected]
http://lists.iptel.org/mailman/listinfo/semsdev

Reply via email to